@@ -4,7 +4,7 @@ import sys
 if sys.version_info < (3, 5):
     raise EnvironmentError("Python 3.5 or above is required")
 
-from eth_account import Account  # noqa: E402
+from platon_account import Account  # noqa: E402
 from client_sdk_python.main import Web3  # noqa: E402
 from client_sdk_python.providers.rpc import (  # noqa: E402
     HTTPProvider,
