@@ -250,7 +250,6 @@ class Pip(Module):
         todo fill
         """
         if module is None:
-            data = rlp.encode([rlp.encode(int(2106))])
-        else:
-            data = rlp.encode([rlp.encode(int(2106)), rlp.encode(module)])
+            module = ""
+        data = rlp.encode([rlp.encode(int(2106)), rlp.encode(module)])
         return parse_data(call_obj(self, from_address, self.web3.pipAddress, data))
